@@ -1,6 +1,6 @@
 
 package App::FQStat::Config;
-# App::FQStat is (c) 2007-2008 Steffen Mueller
+# App::FQStat is (c) 2007-2009 Steffen Mueller
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
@@ -114,6 +114,9 @@ sub _default_config {
     version => $App::FQStat::VERSION,
     colors => $App::FQStat::Colors::DefaultColors,
     color_schemes => $App::FQStat::Colors::DefaultColorSchemes,
+    summary_mode => 0,
+    summary_clustering => 0,
+    summary_clustering_similarity => 0.25,
   );
 
   my %upgrades;
@@ -121,7 +124,6 @@ sub _default_config {
     old => sub {
       my $cfg = shift;
       %$cfg = %default;
-      save_configuration();
     },
     '6.0' => sub {
       my $cfg = shift;
@@ -132,6 +134,16 @@ sub _default_config {
     '6.1' => sub {
       my $cfg = shift;
       $cfg->{color_schemes} = $App::FQStat::Colors::DefaultColorSchemes;
+      $upgrades{6.2}->($cfg);
+      save_configuration();
+    },
+    '6.2' => sub {
+      my $cfg = shift;
+      foreach my $scheme (values %{$cfg->{color_schemes}}) {
+        $scheme->{summary} = $scheme->{user_highlight};
+      }
+      $cfg->{colors}->{summary} = $cfg->{colors}->{user_highlight};
+      $cfg->{summary_clustering_similarity} = 0.25;
       save_configuration();
     },
   );
